# softwrdwrangler
It will wrangle various aws resources 

## Installation
```bash
pip install softwrdwrangler
```

## Usage
```python
import softwrdwrangler as swr

data = swr.read_pickle(<s3_uri>)
```

## License
Apache Software License
```